@@ -4,7 +4,7 @@ use base qw(Business::ISBN);
 
 use Business::ISBN qw(:all);
 
-use subs qw( 
+use subs qw(
 	_checksum
 	INVALID_GROUP_CODE
 	INVALID_PUBLISHER_CODE
@@ -13,41 +13,39 @@ use subs qw(
 	BAD_ISBN
 	);
 
-use vars qw( 
-	$VERSION 
-	$debug 
-	$MAX_GROUP_CODE_LENGTH 
-	%ERROR_TEXT 
+use vars qw(
+	$VERSION
+	$debug
+	$MAX_GROUP_CODE_LENGTH
+	%ERROR_TEXT
 	);
 
 use Carp qw(carp croak cluck);
 
 my $debug = 0;
 
-$VERSION   = '2.05_03';
+$VERSION   = '2.09_01';
 
 sub _max_length { 10 }
 
-sub _set_type     { $_[0]->{type} = 'ISBN10' }
+sub _set_type { $_[0]->{type} = 'ISBN10' }
 
 sub _parse_prefix { '' }
-sub _set_prefix   
-	{ 
+sub _set_prefix {
 	croak "Cannot set prefix [$_[1]] on an ISBN-10" if length $_[1];
-	
+
 	$_[0]->{prefix} = $_[1];
 	}
 
-sub _hyphen_positions { 
+sub _hyphen_positions {
 	[
 	$_[0]->_group_code_length,
 	$_[0]->_group_code_length + $_[0]->_publisher_code_length,
 	9
 	]
-	}	
-	
-sub as_isbn10
-	{
+	}
+
+sub as_isbn10 {
 	my $self = shift;
 
 	my $isbn10 = Business::ISBN->new( $self->isbn );
@@ -56,8 +54,7 @@ sub as_isbn10
 	return $isbn10;
 	}
 
-sub as_isbn13
-	{
+sub as_isbn13 {
 	my $self = shift;
 
 	my $isbn13 = Business::ISBN->new( '978' . $self->isbn );
@@ -67,8 +64,7 @@ sub as_isbn13
 	}
 
 #internal function.  you don't get to use this one.
-sub _checksum
-	{
+sub _checksum {
 	my $data = $_[0]->isbn;
 
 	return unless defined $data;
@@ -76,8 +72,7 @@ sub _checksum
 	my @digits = split //, $data;
 	my $sum    = 0;
 
-	foreach( reverse 2..10 )
-		{
+	foreach( reverse 2..10 ) {
 		$sum += $_ * (shift @digits);
 		}
 
@@ -94,6 +89,8 @@ sub _checksum
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Business::ISBN10 - work with 10 digit International Standard Book Numbers
@@ -110,7 +107,7 @@ See L<Business::ISBN>
 
 This source is in Github:
 
-    http://github.com/briandfoy/business--isbn/tree/master
+    https://github.com/briandfoy/business--isbn
 
 =head1 AUTHOR
 
@@ -118,7 +115,7 @@ brian d foy C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2001-2011, brian d foy, All Rights Reserved.
+Copyright © 2001-2015, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
